from typing import Optional
from math import floor, sqrt
from spacy.language import Language
from spacy.tokens import Doc

@Language.factory("readability")
def get_readability(nlp: Language, name: str):
    return Readability(nlp, name)

class Readability:
    def __init__(self, nlp: Language, name: str = "readability"):

        """
        nlp: an instance of spacy
        """
        self.nlp = nlp
        self.name = "readability"
        self.common = DC_3000


    def flesch_reading_ease(self, counts, scores):
        return round(206.835 - (1.015 * scores["ASL"]) - (84.6 * scores["ASW"]),2)

    def flesch_kincaid_grade(self, counts, scores):
        return round((0.39 * scores["ASL"]) + (11.8 * scores["ASW"]) - 15.59,2)

    def automated_readability_index(self, counts, scores):
        return round((4.71 * scores["AWL"]) + (0.5 * scores["ASL"]) - 21.43,2)

    def smog_index(self, counts, scores):
        return round(1.0430 * sqrt(counts["poly"] * (30 / counts["sentences"])) + 3.1291,2)

    def dale_chall(self, counts, scores):
        base = 3.6365 if scores["uncommon_index"] > 5 else 0
        return round(base + (0.1579 * scores["uncommon_index"]) + (0.0496 * scores["ASL"]), 2)

    def dale_chall_grade(self, counts, scores):
        return 4 + ((floor(scores["dale_chall"]) - 4) * 2)

    def get_uncommon(self, doc):
        return [t.text for t in doc if t.is_alpha and t.pos_ != "PROPN" and t.lower_ not in self.common]

    def get_counts(self, doc):
        words = [t for t in doc if t.is_alpha]
        return {
            "sentences": len([s for s in doc.sents if len(s.text.strip()) > 0]),
            "words": len(words),
            "stop": len([w for w in doc if w.is_stop]),
            "syllables": sum([w._.syllables_count for w in words]),
            "characters": sum([len(w.text.strip()) for w in words]),
            "poly": len([w for w in words if w._.syllables_count > 2]),
            "uncommon": len(doc._.uncommon),
            #"passive": len(doc.spans["passive"])
        }


    def get_scores(self, counts):
        scores = {}

        scores["ASL"] = 0
        scores["ASW"] = 0
        scores["AWL"] = 0
        scores["flesch_reading_ease"] = 0
        scores["flesch_kincaid_grade"] = 0
        scores["automated_readability_index"] = 0
        scores["smog_index"] = 0
        #scores["passive_index"] = 0
        scores["uncommon_index"] = 0
        scores["poly_index"] = 0
        scores["dale_chall"] = 0
        scores["dale_chall_grade"] = 0

        if counts["words"] > 0 and counts["sentences"] > 0:
            scores["ASL"] = round(counts["words"] / counts["sentences"], 2)
            scores["AWL"] = round(counts["characters"] / counts["words"], 2)
            scores["ASW"] = round(counts["syllables"] / counts["words"], 2)
            #scores["passive_index"] = round((counts["passive"]/counts["sentences"] * 100),2)
            scores["poly_index"] = round((counts["poly"]/counts["words"] * 100),2)
            scores["uncommon_index"] = round((counts["uncommon"]/counts["words"] * 100),2)
            scores["flesch_reading_ease"] = self.flesch_reading_ease(counts, scores)
            scores["flesch_kincaid_grade"] = self.flesch_kincaid_grade(counts, scores)
            scores["automated_readability_index"] = self.automated_readability_index(counts, scores)
            scores["smog_index"] = self.smog_index(counts, scores)
            scores["dale_chall"] = self.dale_chall(counts, scores)
            scores["dale_chall_grade"] = self.dale_chall_grade(counts, scores)

        return scores


    def __call__(self, doc):
        # Add the extension to Doc
        Doc.set_extension("readability", default=None, force=True)
        Doc.set_extension("counts", default=None, force=True)
        Doc.set_extension("uncommon", default=None, force=True)

        doc._.uncommon = self.get_uncommon(doc)
        doc._.counts = self.get_counts(doc)
        doc._.readability = self.get_scores(doc._.counts)

        if not hasattr(doc, 'cats'):
            doc.cats = {}

        for score in doc._.readability:
            doc.cats[score] = doc._.readability[score]

        for score in doc._.counts:
            doc.cats[score] = doc._.counts[score]

        doc.cats[score] = doc._.formality

        return doc

#
# DALE-CHALL 3000 common words
#
DC_3000 = """a
able
aboard
about
above
absent
accept
accident
account
ache
aching
acorn
acre
across
act
acts
add
address
admire
adventure
afar
afraid
after
afternoon
afterward
afterwards
again
against
age
aged
ago
agree
ah
ahead
aid
aim
air
airfield
airplane
airport
airship
airy
alarm
alike
alive
all
alley
alligator
allow
almost
alone
along
aloud
already
also
always
am
America
American
among
amount
an
and
angel
anger
angry
animal
another
answer
ant
any
anybody
anyhow
anyone
anything
anyway
anywhere
apart
apartment
ape
apiece
appear
apple
April
apron
are
aren't
arise
arithmetic
arm
armful
army
arose
around
arrange
arrive
arrived
arrow
art
artist
as
ash
ashes
aside
ask
asleep
at
ate
attack
attend
attention
August
aunt
author
auto
automobile
autumn
avenue
awake
awaken
away
awful
awfully
awhile
ax
axe
baa
babe
babies
back
background
backward
backwards
bacon
bad
badge
badly
bag
bake
baker
bakery
baking
ball
balloon
banana
band
bandage
bang
banjo
bank
banker
bar
barber
bare
barefoot
barely
bark
barn
barrel
base
baseball
basement
basket
bat
batch
bath
bathe
bathing
bathroom
bathtub
battle
battleship
bay
be
beach
bead
beam
bean
bear
beard
beast
beat
beating
beautiful
beautify
beauty
became
because
become
becoming
bed
bedbug
bedroom
bedspread
bedtime
bee
beech
beef
beefsteak
beehive
been
beer
beet
before
beg
began
beggar
begged
begin
beginning
begun
behave
behind
being
believe
bell
belong
below
belt
bench
bend
beneath
bent
berries
berry
beside
besides
best
bet
better
between
bib
bible
bicycle
bid
big
bigger
bill
billboard
bin
bind
bird
birth
birthday
biscuit
bit
bite
biting
bitter
black
blackberry
blackbird
blackboard
blackness
blacksmith
blame
blank
blanket
blast
blaze
bleed
bless
blessing
blew
blind
blindfold
blinds
block
blood
bloom
blossom
blot
blow
blue
blueberry
bluebird
blush
board
boast
boat
bob
bobwhite
bodies
body
boil
boiler
bold
bone
bonnet
boo
book
bookcase
bookkeeper
boom
boot
born
borrow
boss
both
bother
bottle
bottom
bought
bounce
bow
bowl
bow-wow
box
boxcar
boxer
boxes
boy
boyhood
bracelet
brain
brake
bran
branch
brass
brave
bread
break
breakfast
breast
breath
breathe
breeze
brick
bride
bridge
bright
brightness
bring
broad
broadcast
broke
broken
brook
broom
brother
brought
brown
brush
bubble
bucket
buckle
bud
buffalo
bug
buggy
build
building
built
bulb
bull
bullet
bum
bumblebee
bump
bun
bunch
bundle
bunny
burn
burst
bury
bus
bush
bushel
business
busy
but
butcher
butt
butter
buttercup
butterfly
buttermilk
butterscotch
button
buttonhole
buy
buzz
by
bye
cab
cabbage
cabin
cabinet
cackle
cage
cake
calendar
calf
call
caller
calling
came
camel
camp
campfire
can
canal
canary
candle
candlestick
candy
cane
cannon
cannot
canoe
can't
canyon
cap
cape
capital
captain
car
card
cardboard
care
careful
careless
carelessness
carload
carpenter
carpet
carriage
carrot
carry
cart
carve
case
cash
cashier
castle
cat
catbird
catch
catcher
caterpillar
catfish
catsup
cattle
caught
cause
cave
ceiling
cell
cellar
cent
center
cereal
certain
certainly
chain
chair
chalk
champion
chance
change
chap
charge
charm
chart
chase
chatter
cheap
cheat
check
checkers
cheek
cheer
cheese
cherry
chest
chew
chick
chicken
chief
child
childhood
children
chill
chilly
chimney
chin
china
chip
chipmunk
chocolate
choice
choose
chop
chorus
chose
chosen
christen
Christmas
church
churn
cigarette
circle
circus
citizen
city
clang
clap
class
classmate
classroom
claw
clay
clean
cleaner
clear
clerk
clever
click
cliff
climb
clip
cloak
clock
close
closet
cloth
clothes
clothing
cloud
cloudy
clover
clown
club
cluck
clump
coach
coal
coast
coat
cob
cobbler
cocoa
coconut
cocoon
cod
codfish
coffee
coffeepot
coin
cold
collar
college
color
colored
colt
column
comb
come
comfort
comic
coming
company
compare
conductor
cone
connect
coo
cook
cooked
cooking
cookie
cookies
cool
cooler
coop
copper
copy
cord
cork
corn
corner
correct
cost
cot
cottage
cotton
couch
cough
could
couldn't
count
counter
country
county
course
court
cousin
cover
cow
coward
cowardly
cowboy
cozy
crab
crack
cracker
cradle
cramps
cranberry
crank
cranky
crash
crawl
crazy
cream
creamy
creek
creep
crept
cried
croak
crook
crooked
crop
cross
crossing
cross-eyed
crow
crowd
crowded
crown
cruel
crumb
crumble
crush
crust
cry
cries
cub
cuff
cup
cuff
cup
cupboard
cupful
cure
curl
curly
curtain
curve
cushion
custard
customer
cut
cute
cutting
dab
dad
daddy
daily
dairy
daisy
dam
damage
dame
damp
dance
dancer
dancing
dandy
danger
dangerous
dare
dark
darkness
darling
darn
dart
dash
date
daughter
dawn
day
daybreak
daytime
dead
deaf
deal
dear
death
December
decide
deck
deed
deep
deer
defeat
defend
defense
delight
den
dentist
depend
deposit
describe
desert
deserve
desire
desk
destroy
devil
dew
diamond
did
didn't
die
died
dies
difference
different
dig
dim
dime
dine
ding-dong
dinner
dip
direct
direction
dirt
dirty
discover
dish
dislike
dismiss
ditch
dive
diver
divide
do
dock
doctor
does
doesn't
dog
doll
dollar
dolly
done
donkey
don't
door
doorbell
doorknob
doorstep
dope
dot
double
dough
dove
down
downstairs
downtown
dozen
drag
drain
drank
draw
drawer
draw
drawing
dream
dress
dresser
dressmaker
drew
dried
drift
drill
drink
drip
drive
driven
driver
drop
drove
drown
drowsy
drub
drum
drunk
dry
duck
due
dug
dull
dumb
dump
during
dust
dusty
duty
dwarf
dwell
dwelt
dying
each
eager
eagle
ear
early
earn
earth
east
eastern
easy
eat
eaten
edge
egg
eh
eight
eighteen
eighth
eighty
either
elbow
elder
eldest
electric
electricity
elephant
eleven
elf
elm
else
elsewhere
empty
end
ending
enemy
engine
engineer
English
enjoy
enough
enter
envelope
equal
erase
eraser
errand
escape
eve
even
evening
ever
every
everybody
everyday
everyone
everything
everywhere
evil
exact
except
exchange
excited
exciting
excuse
exit
expect
explain
extra
eye
eyebrow
fable
face
facing
fact
factory
fail
faint
fair
fairy
faith
fake
fall
false
family
fan
fancy
far
faraway
fare
farmer
farm
farming
far-off
farther
fashion
fast
fasten
fat
father
fault
favor
favorite
fear
feast
feather
February
fed
feed
feel
feet
fell
fellow
felt
fence
fever
few
fib
fiddle
field
fife
fifteen
fifth
fifty
fig
fight
figure
file
fill
film
finally
find
fine
finger
finish
fire
firearm
firecracker
fireplace
fireworks
firing
first
fish
fisherman
fist
fit
fits
five
fix
flag
flake
flame
flap
flash
flashlight
flat
flea
flesh
flew
flies
flight
flip
flip-flop
float
flock
flood
floor
flop
flour
flow
flower
flowery
flutter
fly
foam
fog
foggy
fold
folks
follow
following
fond
food
fool
foolish
foot
football
footprint
for
forehead
forest
forget
forgive
forgot
forgotten
fork
form
fort
forth
fortune
forty
forward
fought
found
fountain
four
fourteen
fourth
fox
frame
free
freedom
freeze
freight
French
fresh
fret
Friday
fried
friend
friendly
friendship
frighten
frog
from
front
frost
frown
froze
fruit
fry
fudge
fuel
full
fully
fun
funny
fur
furniture
further
fuzzy
gain
gallon
gallop
game
gang
garage
garbage
garden
gas
gasoline
gate
gather
gave
gay
gear
geese
general
gentle
gentleman
gentlemen
geography
get
getting
giant
gift
gingerbread
girl
give
given
giving
glad
gladly
glance
glass
glasses
gleam
glide
glory
glove
glow
glue
go
going
goes
goal
goat
gobble
God
god
godmother
gold
golden
goldfish
golf
gone
good
goods
goodbye
good-by
goodbye
good-bye
good-looking
goodness
goody
goose
gooseberry
got
govern
government
gown
grab
gracious
grade
grain
grand
grandchild
grandchildren
granddaughter
grandfather
grandma
grandmother
grandpa
grandson
grandstand
grape
grapes
grapefruit
grass
grasshopper
grateful
grave
gravel
graveyard
gravy
gray
graze
grease
great
green
greet
grew
grind
groan
grocery
ground
group
grove
grow
guard
guess
guest
guide
gulf
gum
gun
gunpowder
guy
ha
habit
had
hadn't
hail
hair
haircut
hairpin
half
hall
halt
ham
hammer
hand
handful
handkerchief
handle
handwriting
hang
happen
happily
happiness
happy
harbor
hard
hardly
hardship
hardware
hare
hark
harm
harness
harp
harvest
has
hasn't
haste
hasten
hasty
hat
hatch
hatchet
hate
haul
have
haven't
having
hawk
hay
hayfield
haystack
he
head
headache
heal
health
healthy
heap
hear
hearing
heard
heart
heat
heater
heaven
heavy
he'd
heel
height
held
hell
he'll
hello
helmet
help
helper
helpful
hem
hen
henhouse
her
hers
herd
here
here's
hero
herself
he's
hey
hickory
hid
hidden
hide
high
highway
hill
hillside
hilltop
hilly
him
himself
hind
hint
hip
hire
his
hiss
history
hit
hitch
hive
ho
hoe
hog
hold
holder
hole
holiday
hollow
holy
home
homely
homesick
honest
honey
honeybee
honeymoon
honk
honor
hood
hoof
hook
hoop
hop
hope
hopeful
hopeless
horn
horse
horseback
horseshoe
hose
hospital
host
hot
hotel
hound
hour
house
housetop
housewife
housework
how
however
howl
hug
huge
hum
humble
hump
hundred
hung
hunger
hungry
hunk
hunt
hunter
hurrah
hurried
hurry
hurt
husband
hush
hut
hymn
I
ice
icy
I'd
idea
ideal
if
ill
I'll
I'm
important
impossible
improve
in
inch
inches
income
indeed
Indian
indoors
ink
inn
insect
inside
instant
instead
insult
intend
interested
interesting
into
invite
iron
is
island
isn't
it
its
it's
itself
I've
ivory
ivy
jacket
jacks
jail
jam
January
jar
jaw
jay
jelly
jellyfish
jerk
jig
job
jockey
join
joke
joking
jolly
journey
joy
joyful
joyous
judge
jug
juice
juicy
July
jump
June
junior
junk
just
keen
keep
kept
kettle
key
kick
kid
kill
killed
kind
kindly
kindness
king
kingdom
kiss
kitchen
kite
kitten
kitty
knee
kneel
knew
knife
knit
knives
knob
knock
knot
know
known
lace
lad
ladder
ladies
lady
laid
lake
lamb
lame
lamp
land
lane
language
lantern
lap
lard
large
lash
lass
last
late
laugh
laundry
law
lawn
lawyer
lay
lazy
lead
leader
leaf
leak
lean
leap
learn
learned
least
leather
leave
leaving
led
left
leg
lemon
lemonade
lend
length
less
lesson
let
let's
letter
letting
lettuce
level
liberty
library
lice
lick
lid
lie
life
lift
light
lightness
lightning
like
likely
liking
lily
limb
lime
limp
line
linen
lion
lip
list
listen
lit
little
live
lives
lively
liver
living
lizard
load
loaf
loan
loaves
lock
locomotive
log
lone
lonely
lonesome
long
look
lookout
loop
loose
lord
lose
loser
loss
lost
lot
loud
love
lovely
lover
low
luck
lucky
lumber
lump
lunch
lying
ma
machine
machinery
mad
made
magazine
magic
maid
mail
mailbox
mailman
major
make
making
male
mama
mamma
man
manager
mane
manger
many
map
maple
marble
march
March
mare
mark
market
marriage
married
marry
mask
mast
master
mat
match
matter
mattress
may
May
maybe
mayor
maypole
me
meadow
meal
mean
means
meant
measure
meat
medicine
meet
meeting
melt
member
men
mend
meow
merry
mess
message
met
metal
mew
mice
middle
midnight
might
mighty
mile
milk
milkman
mill
miler
million
mind
mine
miner
mint
minute
mirror
mischief
miss
Miss
misspell
mistake
misty
mitt
mitten
mix
moment
Monday
money
monkey
month
moo
moon
moonlight
moose
mop
more
morning
morrow
moss
most
mostly
mother
motor
mount
mountain
mouse
mouth
move
movie
movies
moving
mow
Mr.
Mrs.
much
mud
muddy
mug
mule
multiply
murder
music
must
my
myself
nail
name
nap
napkin
narrow
nasty
naughty
navy
near
nearby
nearly
neat
neck
necktie
need
needle
needn't
Negro
neighbor
neighborhood
neither
nerve
nest
net
never
nevermore
new
news
newspaper
next
nibble
nice
nickel
night
nightgown
nine
nineteen
ninety
no
nobody
nod
noise
noisy
none
noon
nor
north
northern
nose
not
note
nothing
notice
November
now
nowhere
number
nurse
nut
oak
oar
oatmeal
oats
obey
ocean
o'clock
October
odd
of
off
offer
office
officer
often
oh
oil
old
old-fashioned
on
once
one
onion
only
onward
open
or
orange
orchard
order
ore
organ
other
otherwise
ouch
ought
our
ours
ourselves
out
outdoors
outfit
outlaw
outline
outside
outward
oven
over
overalls
overcoat
overeat
overhead
overhear
overnight
overturn
owe
owing
owl
own
owner
ox
pa
pace
pack
package
pad
page
paid
pail
pain
painful
paint
painter
painting
pair
pal
palace
pale
pan
pancake
pane
pansy
pants
papa
paper
parade
pardon
parent
park
part
partly
partner
party
pass
passenger
past
paste
pasture
pat
patch
path
patter
pave
pavement
paw
pay
payment
pea
peas
peace
peaceful
peach
peaches
peak
peanut
pear
pearl
peck
peek
peel
peep
peg
pen
pencil
penny
people
pepper
peppermint
perfume
perhaps
person
pet
phone
piano
pick
pickle
picnic
picture
pie
piece
pig
pigeon
piggy
pile
pill
pillow
pin
pine
pineapple
pink
pint
pipe
pistol
pit
pitch
pitcher
pity
place
plain
plan
plane
plant
plate
platform
platter
play
player
playground
playhouse
playmate
plaything
pleasant
please
pleasure
plenty
plow
plug
plum
pocket
pocketbook
poem
point
poison
poke
pole
police
policeman
polish
polite
pond
ponies
pony
pool
poor
pop
popcorn
popped
porch
pork
possible
post
postage
postman
pot
potato
potatoes
pound
pour
powder
power
powerful
praise
pray
prayer
prepare
present
pretty
price
prick
prince
princess
print
prison
prize
promise
proper
protect
proud
prove
prune
public
puddle
puff
pull
pump
pumpkin
punch
punish
pup
pupil
puppy
pure
purple
purse
push
puss
pussy
pussycat
put
putting
puzzle
quack
quart
quarter
queen
queer
question
quick
quickly
quiet
quilt
quit
quite
rabbit
race
rack
radio
radish
rag
rail
railroad
railway
rain
rainy
rainbow
raise
raisin
rake
ram
ran
ranch
rang
rap
rapidly
rat
rate
rather
rattle
raw
ray
reach
read
reader
reading
ready
real
really
reap
rear
reason
rebuild
receive
recess
record
red
redbird
redbreast
refuse
reindeer
rejoice
remain
remember
remind
remove
rent
repair
repay
repeat
report
rest
return
review
reward
rib
ribbon
rice
rich
rid
riddle
ride
rider
riding
right
rim
ring
rip
ripe
rise
rising
river
road
roadside
roar
roast
rob
robber
robe
robin
rock
rocky
rocket
rode
roll
roller
roof
room
rooster
root
rope
rose
rosebud
rot
rotten
rough
round
route
row
rowboat
royal
rub
rubbed
rubber
rubbish
rug
rule
ruler
rumble
run
rung
runner
running
rush
rust
rusty
rye
sack
sad
saddle
sadness
safe
safety
said
sail
sailboat
sailor
saint
salad
sale
salt
same
sand
sandy
sandwich
sang
sank
sap
sash
sat
satin
satisfactory
Saturday
sausage
savage
save
savings
saw
say
scab
scales
scare
scarf
school
schoolboy
schoolhouse
schoolmaster
schoolroom
scorch
score
scrap
scrape
scratch
scream
screen
screw
scrub
sea
seal
seam
search
season
seat
second
secret
see
seeing
seed
seek
seem
seen
seesaw
select
self
selfish
sell
send
sense
sent
sentence
separate
September
servant
serve
service
set
setting
settle
settlement
seven
seventeen
seventh
seventy
several
sew
shade
shadow
shady
shake
shaker
shaking
shall
shame
shan't
shape
share
sharp
shave
she
she'd
she'll
she's
shear
shears
shed
sheep
sheet
shelf
shell
shepherd
shine
shining
shiny
ship
shirt
shock
shoe
shoemaker
shone
shook
shoot
shop
shopping
shore
short
shot
should
shoulder
shouldn't
shout
shovel
show
shower
shut
shy
sick
sickness
side
sidewalk
sideways
sigh
sight
sign
silence
silent
silk
sill
silly
silver
simple
sin
since
sing
singer
single
sink
sip
sir
sis
sissy
sister
sit
sitting
six
sixteen
sixth
sixty
size
skate
skater
ski
skin
skip
skirt
sky
slam
slap
slate
slave
sled
sleep
sleepy
sleeve
sleigh
slept
slice
slid
slide
sling
slip
slipped
slipper
slippery
slit
slow
slowly
sly
smack
small
smart
smell
smile
smoke
smooth
snail
snake
snap
snapping
sneeze
snow
snowy
snowball
snowflake
snuff
snug
so
soak
soap
sob
socks
sod
soda
sofa
soft
soil
sold
soldier
sole
some
somebody
somehow
someone
something
sometime
sometimes
somewhere
son
song
soon
sore
sorrow
sorry
sort
soul
sound
soup
sour
south
southern
space
spade
spank
sparrow
speak
speaker
spear
speech
speed
spell
spelling
spend
spent
spider
spike
spill
spin
spinach
spirit
spit
splash
spoil
spoke
spook
spoon
sport
spot
spread
spring
springtime
sprinkle
square
squash
squeak
squeeze
squirrel
stable
stack
stage
stair
stall
stamp
stand
star
stare
start
starve
state
station
stay
steak
steal
steam
steamboat
steamer
steel
steep
steeple
steer
stem
step
stepping
stick
sticky
stiff
still
stillness
sting
stir
stitch
stock
stocking
stole
stone
stood
stool
stoop
stop
stopped
stopping
store
stork
stories
storm
stormy
story
stove
straight
strange
stranger
strap
straw
strawberry
stream
street
stretch
string
strip
stripes
strong
stuck
study
stuff
stump
stung
subject
such
suck
sudden
suffer
sugar
suit
sum
summer
sun
Sunday
sunflower
sung
sunk
sunlight
sunny
sunrise
sunset
sunshine
supper
suppose
sure
surely
surface
surprise
swallow
swam
swamp
swan
swat
swear
sweat
sweater
sweep
sweet
sweetness
sweetheart
swell
swept
swift
swim
swimming
swing
switch
sword
swore
table
tablecloth
tablespoon
tablet
tack
tag
tail
tailor
take
taken
taking
tale
talk
talker
tall
tame
tan
tank
tap
tape
tar
tardy
task
taste
taught
tax
tea
teach
teacher
team
tear
tease
teaspoon
teeth
telephone
tell
temper
ten
tennis
tent
term
terrible
test
than
thank
thanks
thankful
Thanksgiving
that
that's
the
theater
thee
their
them
then
there
these
they
they'd
they'll
they're
they've
thick
thief
thimble
thin
thing
think
third
thirsty
thirteen
thirty
this
thorn
those
though
thought
thousand
thread
three
threw
throat
throne
through
throw
thrown
thumb
thunder
Thursday
thy
tick
ticket
tickle
tie
tiger
tight
till
time
tin
tinkle
tiny
tip
tiptoe
tire
tired
title
to
toad
toadstool
toast
tobacco
today
toe
together
toilet
told
tomato
tomorrow
ton
tone
tongue
tonight
too
took
tool
toot
tooth
toothbrush
toothpick
top
tore
torn
toss
touch
tow
toward
towards
towel
tower
town
toy
trace
track
trade
train
tramp
trap
tray
treasure
treat
tree
trick
tricycle
tried
trim
trip
trolley
trouble
truck
true
truly
trunk
trust
truth
try
tub
Tuesday
tug
tulip
tumble
tune
tunnel
turkey
turn
turtle
twelve
twenty
twice
twig
twin
two
ugly
umbrella
uncle
under
understand
underwear
undress
unfair
unfinished
unfold
unfriendly
unhappy
unhurt
uniform
United
States
unkind
unknown
unless
unpleasant
until
unwilling
up
upon
upper
upset
upside
upstairs
uptown
upward
us
use
used
useful
valentine
valley
valuable
value
vase
vegetable
velvet
very
vessel
victory
view
village
vine
violet
visit
visitor
voice
vote
wag
wagon
waist
wait
wake
waken
walk
wall
walnut
want
war
warm
warn
was
wash
washer
washtub
wasn't
waste
watch
watchman
water
watermelon
waterproof
wave
wax
way
wayside
we
weak
weakness
weaken
wealth
weapon
wear
weary
weather
weave
web
we'd
wedding
Wednesday
wee
weed
week
we'll
weep
weigh
welcome
well
went
were
we're
west
western
wet
we've
whale
what
what's
wheat
wheel
when
whenever
where
which
while
whip
whipped
whirl
whisky
whiskey
whisper
whistle
white
who
who'd
whole
who'll
whom
who's
whose
why
wicked
wide
wife
wiggle
wild
wildcat
will
willing
willow
win
wind
windy
windmill
window
wine
wing
wink
winner
winter
wipe
wire
wise
wish
wit
witch
with
without
woke
wolf
woman
women
won
wonder
wonderful
won't
wood
wooden
woodpecker
woods
wool
woolen
word
wore
work
worker
workman
world
worm
worn
worry
worse
worst
worth
would
wouldn't
wound
wove
wrap
wrapped
wreck
wren
wring
write
writing
written
wrong
wrote
wrung
yard
yarn
year
yell
yellow
yes
yesterday
yet
yolk
yonder
you
you'd
you'll
young
youngster
your
yours
you're
yourself
yourselves
youth
you've""".split("\n")

EF_3000 = """
a
abandon
ability
able
abortion
about
above
abroad
absence
absolute
absolutely
absorb
abuse
academic
accept
access
accident
accompany
accomplish
according
account
accurate
accuse
achieve
achievement
acid
acknowledge
acquire
across
act
action
active
activist
activity
actor
actress
actual
actually
ad
adapt
add
addition
additional
address
adequate
adjust
adjustment
administration
administrator
admire
admission
admit
adolescent
adopt
adult
advance
advanced
advantage
adventure
advertising
advice
advise
adviser
advocate
affair
affect
afford
afraid
African
African-American
after
afternoon
again
against
age
agency
agenda
agent
aggressive
ago
agree
agreement
agricultural
ah
ahead
aid
aide
AIDS
aim
air
aircraft
airline
airport
album
alcohol
alive
all
alliance
allow
ally
almost
alone
along
already
also
alter
alternative
although
always
AM
amazing
American
among
amount
analysis
analyst
analyze
ancient
and
anger
angle
angry
animal
anniversary
announce
annual
another
answer
anticipate
anxiety
any
anybody
anymore
anyone
anything
anyway
anywhere
apart
apartment
apparent
apparently
appeal
appear
appearance
apple
application
apply
appoint
appointment
appreciate
approach
appropriate
approval
approve
approximately
Arab
architect
area
argue
argument
arise
arm
armed
army
around
arrange
arrangement
arrest
arrival
arrive
art
article
artist
artistic
as
Asian
aside
ask
asleep
aspect
assault
assert
assess
assessment
asset
assign
assignment
assist
assistance
assistant
associate
association
assume
assumption
assure
at
athlete
athletic
atmosphere
attach
attack
attempt
attend
attention
attitude
attorney
attract
attractive
attribute
audience
author
authority
auto
available
average
avoid
award
aware
awareness
away
awful
baby
back
background
bad
badly
bag
bake
balance
ball
ban
band
bank
bar
barely
barrel
barrier
base
baseball
basic
basically
basis
basket
basketball
bathroom
battery
battle
be
beach
bean
bear
beat
beautiful
beauty
because
become
bed
bedroom
beer
before
begin
beginning
behavior
behind
being
belief
believe
bell
belong
below
belt
bench
bend
beneath
benefit
beside
besides
best
bet
better
between
beyond
Bible
big
bike
bill
billion
bind
biological
bird
birth
birthday
bit
bite
black
blade
blame
blanket
blind
block
blood
blow
blue
board
boat
body
bomb
bombing
bond
bone
book
boom
boot
border
born
borrow
boss
both
bother
bottle
bottom
boundary
bowl
box
boy
boyfriend
brain
branch
brand
bread
break
breakfast
breast
breath
breathe
brick
bridge
brief
briefly
bright
brilliant
bring
British
broad
broken
brother
brown
brush
buck
budget
build
building
bullet
bunch
burden
burn
bury
bus
business
busy
but
butter
button
buy
buyer
by
cabin
cabinet
cable
cake
calculate
call
camera
camp
campaign
campus
can
Canadian
cancer
candidate
cap
capability
capable
capacity
capital
captain
capture
car
carbon
card
care
career
careful
carefully
carrier
carry
case
cash
cast
cat
catch
category
Catholic
cause
ceiling
celebrate
celebration
celebrity
cell
center
central
century
CEO
ceremony
certain
certainly
chain
chair
chairman
challenge
chamber
champion
championship
chance
change
changing
channel
chapter
character
characteristic
characterize
charge
charity
chart
chase
cheap
check
cheek
cheese
chef
chemical
chest
chicken
chief
child
childhood
Chinese
chip
chocolate
choice
cholesterol
choose
Christian
Christmas
church
cigarette
circle
circumstance
cite
citizen
city
civil
civilian
claim
class
classic
classroom
clean
clear
clearly
client
climate
climb
clinic
clinical
clock
close
closely
closer
clothes
clothing
cloud
club
clue
cluster
coach
coal
coalition
coast
coat
code
coffee
cognitive
cold
collapse
colleague
collect
collection
collective
college
colonial
color
column
combination
combine
come
comedy
comfort
comfortable
command
commander
comment
commercial
commission
commit
commitment
committee
common
communicate
communication
community
company
compare
comparison
compete
competition
competitive
competitor
complain
complaint
complete
completely
complex
complicated
component
compose
composition
comprehensive
computer
concentrate
concentration
concept
concern
concerned
concert
conclude
conclusion
concrete
condition
conduct
conference
confidence
confident
confirm
conflict
confront
confusion
Congress
congressional
connect
connection
consciousness
consensus
consequence
conservative
consider
considerable
consideration
consist
consistent
constant
constantly
constitute
constitutional
construct
construction
consultant
consume
consumer
consumption
contact
contain
container
contemporary
content
contest
context
continue
continued
contract
contrast
contribute
contribution
control
controversial
controversy
convention
conventional
conversation
convert
conviction
convince
cook
cookie
cooking
cool
cooperation
cop
cope
copy
core
corn
corner
corporate
corporation
correct
correspondent
cost
cotton
couch
could
council
counselor
count
counter
country
county
couple
courage
course
court
cousin
cover
coverage
cow
crack
craft
crash
crazy
cream
create
creation
creative
creature
credit
crew
crime
criminal
crisis
criteria
critic
critical
criticism
criticize
crop
cross
crowd
crucial
cry
cultural
culture
cup
curious
current
currently
curriculum
custom
customer
cut
cycle
dad
daily
damage
dance
danger
dangerous
dare
dark
darkness
data
date
daughter
day
dead
deal
dealer
dear
death
debate
debt
decade
decide
decision
deck
declare
decline
decrease
deep
deeply
deer
defeat
defend
defendant
defense
defensive
deficit
define
definitely
definition
degree
delay
deliver
delivery
demand
democracy
Democrat
democratic
demonstrate
demonstration
deny
department
depend
dependent
depending
depict
depression
depth
deputy
derive
describe
description
desert
deserve
design
designer
desire
desk
desperate
despite
destroy
destruction
detail
detailed
detect
determine
develop
developing
development
device
devote
dialogue
die
diet
differ
difference
different
differently
difficult
difficulty
dig
digital
dimension
dining
dinner
direct
direction
directly
director
dirt
dirty
disability
disagree
disappear
disaster
discipline
discourse
discover
discovery
discrimination
discuss
discussion
disease
dish
dismiss
disorder
display
dispute
distance
distant
distinct
distinction
distinguish
distribute
distribution
district
diverse
diversity
divide
division
divorce
DNA
do
doctor
document
dog
domestic
dominant
dominate
door
double
doubt
down
downtown
dozen
draft
drag
drama
dramatic
dramatically
draw
drawing
dream
dress
drink
drive
driver
drop
drug
dry
due
during
dust
duty
each
eager
ear
early
earn
earnings
earth
ease
easily
east
eastern
easy
eat
economic
economics
economist
economy
edge
edition
editor
educate
education
educational
educator
effect
effective
effectively
efficiency
efficient
effort
egg
eight
either
elderly
elect
election
electric
electricity
electronic
element
elementary
eliminate
elite
else
elsewhere
e-mail
embrace
emerge
emergency
emission
emotion
emotional
emphasis
emphasize
employ
employee
employer
employment
empty
enable
encounter
encourage
end
enemy
energy
enforcement
engage
engine
engineer
engineering
English
enhance
enjoy
enormous
enough
ensure
enter
enterprise
entertainment
entire
entirely
entrance
entry
environment
environmental
episode
equal
equally
equipment
era
error
escape
especially
essay
essential
essentially
establish
establishment
estate
estimate
etc
ethics
ethnic
European
evaluate
evaluation
even
evening
event
eventually
ever
every
everybody
everyday
everyone
everything
everywhere
evidence
evolution
evolve
exact
exactly
examination
examine
example
exceed
excellent
except
exception
exchange
exciting
executive
exercise
exhibit
exhibition
exist
existence
existing
expand
expansion
expect
expectation
expense
expensive
experience
experiment
expert
explain
explanation
explode
explore
explosion
expose
exposure
express
expression
extend
extension
extensive
extent
external
extra
extraordinary
extreme
extremely
eye
fabric
face
facility
fact
factor
factory
faculty
fade
fail
failure
fair
fairly
faith
fall
false
familiar
family
famous
fan
fantasy
far
farm
farmer
fashion
fast
fat
fate
father
fault
favor
favorite
fear
feature
federal
fee
feed
feel
feeling
fellow
female
fence
few
fewer
fiber
fiction
field
fifteen
fifth
fifty
fight
fighter
fighting
figure
file
fill
film
final
finally
finance
financial
find
finding
fine
finger
finish
fire
firm
first
fish
fishing
fit
fitness
five
fix
flag
flame
flat
flavor
flee
flesh
flight
float
floor
flow
flower
fly
focus
folk
follow
following
food
foot
football
for
force
foreign
forest
forever
forget
form
formal
formation
former
formula
forth
fortune
forward
found
foundation
founder
four
fourth
frame
framework
free
freedom
freeze
French
frequency
frequent
frequently
fresh
friend
friendly
friendship
from
front
fruit
frustration
fuel
full
fully
fun
function
fund
fundamental
funding
funeral
funny
furniture
furthermore
future
gain
galaxy
gallery
game
gang
gap
garage
garden
garlic
gas
gate
gather
gay
gaze
gear
gender
gene
general
generally
generate
generation
genetic
gentleman
gently
German
gesture
get
ghost
giant
gift
gifted
girl
girlfriend
give
given
glad
glance
glass
global
glove
go
goal
God
gold
golden
golf
good
government
governor
grab
grade
gradually
graduate
grain
grand
grandfather
grandmother
grant
grass
grave
gray
great
greatest
green
grocery
ground
group
grow
growing
growth
guarantee
guard
guess
guest
guide
guideline
guilty
gun
guy
habit
habitat
hair
half
hall
hand
handful
handle
hang
happen
happy
hard
hardly
hat
hate
have
he
head
headline
headquarters
health
healthy
hear
hearing
heart
heat
heaven
heavily
heavy
heel
height
helicopter
hell
hello
help
helpful
her
here
heritage
hero
herself
hey
hi
hide
high
highlight
highly
highway
hill
him
himself
hip
hire
his
historian
historic
historical
history
hit
hold
hole
holiday
holy
home
homeless
honest
honey
honor
hope
horizon
horror
horse
hospital
host
hot
hotel
hour
house
household
housing
how
however
huge
human
humor
hundred
hungry
hunter
hunting
hurt
husband
hypothesis
I
ice
idea
ideal
identification
identify
identity
ie
if
ignore
ill
illegal
illness
illustrate
image
imagination
imagine
immediate
immediately
immigrant
immigration
impact
implement
implication
imply
importance
important
impose
impossible
impress
impression
impressive
improve
improvement
in
incentive
incident
include
including
income
incorporate
increase
increased
increasing
increasingly
incredible
indeed
independence
independent
index
Indian
indicate
indication
individual
industrial
industry
infant
infection
inflation
influence
inform
information
ingredient
initial
initially
initiative
injury
inner
innocent
inquiry
inside
insight
insist
inspire
install
instance
instead
institution
institutional
instruction
instructor
instrument
insurance
intellectual
intelligence
intend
intense
intensity
intention
interaction
interest
interested
interesting
internal
international
Internet
interpret
interpretation
intervention
interview
into
introduce
introduction
invasion
invest
investigate
investigation
investigator
investment
investor
invite
involve
involved
involvement
Iraqi
Irish
iron
Islamic
island
Israeli
issue
it
Italian
item
its
itself
jacket
jail
Japanese
jet
Jew
Jewish
job
join
joint
joke
journal
journalist
journey
joy
judge
judgment
juice
jump
junior
jury
just
justice
justify
keep
key
kick
kid
kill
killer
killing
kind
king
kiss
kitchen
knee
knife
knock
know
knowledge
lab
label
labor
laboratory
lack
lady
lake
land
landscape
language
lap
large
largely
last
late
later
Latin
latter
laugh
launch
law
lawn
lawsuit
lawyer
lay
layer
lead
leader
leadership
leading
leaf
league
lean
learn
learning
least
leather
leave
left
leg
legacy
legal
legend
legislation
legitimate
lemon
length
less
lesson
let
letter
level
liberal
library
license
lie
life
lifestyle
lifetime
lift
light
like
likely
limit
limitation
limited
line
link
lip
list
listen
literally
literary
literature
little
live
living
load
loan
local
locate
location
lock
long
long-term
look
loose
lose
loss
lost
lot
lots
loud
love
lovely
lover
low
lower
luck
lucky
lunch
lung
machine
mad
magazine
mail
main
mainly
maintain
maintenance
major
majority
make
maker
makeup
male
mall
man
manage
management
manager
manner
manufacturer
manufacturing
many
map
margin
mark
market
marketing
marriage
married
marry
mask
mass
massive
master
match
material
math
matter
may
maybe
mayor
me
meal
mean
meaning
meanwhile
measure
measurement
meat
mechanism
media
medical
medication
medicine
medium
meet
meeting
member
membership
memory
mental
mention
menu
mere
merely
mess
message
metal
meter
method
Mexican
middle
might
military
milk
million
mind
mine
minister
minor
minority
minute
miracle
mirror
miss
missile
mission
mistake
mix
mixture
mm-hmm
mode
model
moderate
modern
modest
mom
moment
money
monitor
month
mood
moon
moral
more
moreover
morning
mortgage
most
mostly
mother
motion
motivation
motor
mount
mountain
mouse
mouth
move
movement
movie
Mr
Mrs
Ms
much
multiple
murder
muscle
museum
music
musical
musician
Muslim
must
mutual
my
myself
mystery
myth
naked
name
narrative
narrow
nation
national
native
natural
naturally
nature
near
nearby
nearly
necessarily
necessary
neck
need
negative
negotiate
negotiation
neighbor
neighborhood
neither
nerve
nervous
net
network
never
nevertheless
new
newly
news
newspaper
next
nice
night
nine
no
nobody
nod
noise
nomination
none
nonetheless
nor
normal
normally
north
northern
nose
not
note
nothing
notice
notion
novel
now
nowhere
n't
nuclear
number
numerous
nurse
nut
object
objective
obligation
observation
observe
observer
obtain
obvious
obviously
occasion
occasionally
occupation
occupy
occur
ocean
odd
odds
of
off
offense
offensive
offer
office
officer
official
often
oh
oil
ok
okay
old
Olympic
on
once
one
ongoing
onion
online
only
onto
open
opening
operate
operating
operation
operator
opinion
opponent
opportunity
oppose
opposite
opposition
option
or
orange
order
ordinary
organic
organization
organize
orientation
origin
original
originally
other
others
otherwise
ought
our
ourselves
out
outcome
outside
oven
over
overall
overcome
overlook
owe
own
owner
pace
pack
package
page
pain
painful
paint
painter
painting
pair
pale
Palestinian
palm
pan
panel
pant
paper
parent
park
parking
part
participant
participate
participation
particular
particularly
partly
partner
partnership
party
pass
passage
passenger
passion
past
patch
path
patient
pattern
pause
pay
payment
PC
peace
peak
peer
penalty
people
pepper
per
perceive
percentage
perception
perfect
perfectly
perform
performance
perhaps
period
permanent
permission
permit
person
personal
personality
personally
personnel
perspective
persuade
pet
phase
phenomenon
philosophy
phone
photo
photograph
photographer
phrase
physical
physically
physician
piano
pick
picture
pie
piece
pile
pilot
pine
pink
pipe
pitch
place
plan
plane
planet
planning
plant
plastic
plate
platform
play
player
please
pleasure
plenty
plot
plus
PM
pocket
poem
poet
poetry
point
pole
police
policy
political
politically
politician
politics
poll
pollution
pool
poor
pop
popular
population
porch
port
portion
portrait
portray
pose
position
positive
possess
possibility
possible
possibly
post
pot
potato
potential
potentially
pound
pour
poverty
powder
power
powerful
practical
practice
pray
prayer
precisely
predict
prefer
preference
pregnancy
pregnant
preparation
prepare
prescription
presence
present
presentation
preserve
president
presidential
press
pressure
pretend
pretty
prevent
previous
previously
price
pride
priest
primarily
primary
prime
principal
principle
print
prior
priority
prison
prisoner
privacy
private
probably
problem
procedure
proceed
process
produce
producer
product
production
profession
professional
professor
profile
profit
program
progress
project
prominent
promise
promote
prompt
proof
proper
properly
property
proportion
proposal
propose
proposed
prosecutor
prospect
protect
protection
protein
protest
proud
prove
provide
provider
province
provision
psychological
psychologist
psychology
public
publication
publicly
publish
publisher
pull
punishment
purchase
pure
purpose
pursue
push
put
qualify
quality
quarter
quarterback
question
quick
quickly
quiet
quietly
quit
quite
quote
race
racial
radical
radio
rail
rain
raise
range
rank
rapid
rapidly
rare
rarely
rate
rather
rating
ratio
raw
reach
react
reaction
read
reader
reading
ready
real
reality
realize
really
reason
reasonable
recall
receive
recent
recently
recipe
recognition
recognize
recommend
recommendation
record
recording
recover
recovery
recruit
red
reduce
reduction
refer
reference
reflect
reflection
reform
refugee
refuse
regard
regarding
regardless
regime
region
regional
register
regular
regularly
regulate
regulation
reinforce
reject
relate
relation
relationship
relative
relatively
relax
release
relevant
relief
religion
religious
rely
remain
remaining
remarkable
remember
remind
remote
remove
repeat
repeatedly
replace
reply
report
reporter
represent
representation
representative
Republican
reputation
request
require
requirement
research
researcher
resemble
reservation
resident
resist
resistance
resolution
resolve
resort
resource
respect
respond
respondent
response
responsibility
responsible
rest
restaurant
restore
restriction
result
retain
retire
retirement
return
reveal
revenue
review
revolution
rhythm
rice
rich
rid
ride
rifle
right
ring
rise
risk
river
road
rock
role
roll
romantic
roof
room
root
rope
rose
rough
roughly
round
route
routine
row
rub
rule
run
running
rural
rush
Russian
sacred
sad
safe
safety
sake
salad
salary
sale
sales
salt
same
sample
sanction
sand
satellite
satisfaction
satisfy
sauce
save
saving
say
scale
scandal
scared
scenario
scene
schedule
scheme
scholar
scholarship
school
science
scientific
scientist
scope
score
scream
screen
script
sea
search
season
seat
second
secret
secretary
section
sector
secure
security
see
seed
seek
seem
segment
seize
select
selection
self
sell
Senate
senator
send
senior
sense
sensitive
sentence
separate
sequence
series
serious
seriously
serve
service
session
set
setting
settle
settlement
seven
several
severe
sex
sexual
shade
shadow
shake
shall
shape
share
sharp
she
sheet
shelf
shell
shelter
shift
shine
ship
shirt
shit
shock
shoe
shoot
shooting
shop
shopping
shore
short
shortly
shot
should
shoulder
shout
show
shower
shrug
shut
sick
side
sigh
sight
sign
signal
significance
significant
significantly
silence
silent
silver
similar
similarly
simple
simply
sin
since
sing
singer
single
sink
sir
sister
sit
site
situation
six
size
ski
skill
skin
sky
slave
sleep
slice
slide
slight
slightly
slip
slow
slowly
small
smart
smell
smile
smoke
smooth
snap
snow
so
so-called
soccer
social
society
soft
software
soil
solar
soldier
solid
solution
solve
some
somebody
somehow
someone
something
sometimes
somewhat
somewhere
son
song
soon
sophisticated
sorry
sort
soul
sound
soup
source
south
southern
Soviet
space
Spanish
speak
speaker
special
specialist
species
specific
specifically
speech
speed
spend
spending
spin
spirit
spiritual
split
spokesman
sport
spot
spread
spring
square
squeeze
stability
stable
staff
stage
stair
stake
stand
standard
standing
star
stare
start
state
statement
station
statistics
status
stay
steady
steal
steel
step
stick
still
stir
stock
stomach
stone
stop
storage
store
storm
story
straight
strange
stranger
strategic
strategy
stream
street
strength
strengthen
stress
stretch
strike
string
strip
stroke
strong
strongly
structure
struggle
student
studio
study
stuff
stupid
style
subject
submit
subsequent
substance
substantial
succeed
success
successful
successfully
such
sudden
suddenly
sue
suffer
sufficient
sugar
suggest
suggestion
suicide
suit
summer
summit
sun
super
supply
support
supporter
suppose
supposed
Supreme
sure
surely
surface
surgery
surprise
surprised
surprising
surprisingly
surround
survey
survival
survive
survivor
suspect
sustain
swear
sweep
sweet
swim
swing
switch
symbol
symptom
system
table
tablespoon
tactic
tail
take
tale
talent
talk
tall
tank
tap
tape
target
task
taste
tax
taxpayer
tea
teach
teacher
teaching
team
tear
teaspoon
technical
technique
technology
teen
teenager
telephone
telescope
television
tell
temperature
temporary
ten
tend
tendency
tennis
tension
tent
term
terms
terrible
territory
terror
terrorism
terrorist
test
testify
testimony
testing
text
than
thank
thanks
that
the
theater
their
them
theme
themselves
then
theory
therapy
there
therefore
these
they
thick
thin
thing
think
thinking
third
thirty
this
those
though
thought
thousand
threat
threaten
three
throat
through
throughout
throw
thus
ticket
tie
tight
time
tiny
tip
tire
tired
tissue
title
to
tobacco
today
toe
together
tomato
tomorrow
tone
tongue
tonight
too
tool
tooth
top
topic
toss
total
totally
touch
tough
tour
tourist
tournament
toward
towards
tower
town
toy
trace
track
trade
tradition
traditional
traffic
tragedy
trail
train
training
transfer
transform
transformation
transition
translate
transportation
travel
treat
treatment
treaty
tree
tremendous
trend
trial
tribe
trick
trip
troop
trouble
truck
true
truly
trust
truth
try
tube
tunnel
turn
TV
twelve
twenty
twice
twin
two
type
typical
typically
ugly
ultimate
ultimately
unable
uncle
under
undergo
understand
understanding
unfortunately
uniform
union
unique
unit
United
universal
universe
university
unknown
unless
unlike
unlikely
until
unusual
up
upon
upper
urban
urge
us
use
used
useful
user
usual
usually
utility
vacation
valley
valuable
value
variable
variation
variety
various
vary
vast
vegetable
vehicle
venture
version
versus
very
vessel
veteran
via
victim
victory
video
view
viewer
village
violate
violation
violence
violent
virtually
virtue
virus
visible
vision
visit
visitor
visual
vital
voice
volume
volunteer
vote
voter
vs
vulnerable
wage
wait
wake
walk
wall
wander
want
war
warm
warn
warning
wash
waste
watch
water
wave
way
we
weak
wealth
wealthy
weapon
wear
weather
wedding
week
weekend
weekly
weigh
weight
welcome
welfare
well
west
western
wet
what
whatever
wheel
when
whenever
where
whereas
whether
which
while
whisper
white
who
whole
whom
whose
why
wide
widely
widespread
wife
wild
will
willing
win
wind
window
wine
wing
winner
winter
wipe
wire
wisdom
wise
wish
with
withdraw
within
without
witness
woman
wonder
wonderful
wood
wooden
word
work
worker
working
works
workshop
world
worried
worry
worth
would
wound
wrap
write
writer
writing
wrong
yard
yeah
year
yell
yellow
yes
yesterday
yet
yield
you
young
your
yours
yourself
youth
zone""".split("\n")
